#!/bin/bash -e
#

#
# pygccxml is a product that is always built unqualified
#
# build_pygccxml.sh  <product_directory> [tar]

usage()
{
   echo "USAGE: `basename ${0}` <product_directory> <p2713d|p2714|p2714b> [tar]"
}

# -------------------------------------------------------------------
# shared boilerplate
# -------------------------------------------------------------------

get_this_dir() 
{
    ( cd / ; /bin/pwd -P ) >/dev/null 2>&1
    if (( $? == 0 )); then
      pwd_P_arg="-P"
    fi
    reldir=`dirname ${0}`
    thisdir=`cd ${reldir} && /bin/pwd ${pwd_P_arg}`
}

get_ssibuildshims()
{
    # make sure we can use the setup alias
    if [ -z ${UPS_DIR} ]
    then
       echo "ERROR: please setup ups"
       exit 1
    fi
    source `${UPS_DIR}/bin/ups setup ${SETUP_UPS}`
    
    setup ssibuildshims ${ssibuildshims_version} -z ${product_dir}
}

# -------------------------------------------------------------------
# start processing
# -------------------------------------------------------------------

product_dir=${1}
basequal=${2}
maketar=${3}

if [ -z ${product_dir} ]
then
   echo "ERROR: please specify the local product directory" 1>&2
   usage
   exit 1
fi

if [[ -z "${basequal}" ]] || [[ "${basequal}" == "tar" ]]
then
  echo "Python qualifier is mandatory." 1>&2
  usage
  exit 1
fi

# -------------------------------------------------------------------
# package name and version
# -------------------------------------------------------------------

package=pygccxml
origpkgver=v1_9_1
pkgver=${origpkgver}
ssibuildshims_version=v1_04_02
pkgdotver=`echo ${origpkgver} | sed -e 's/_/./g' -e 's/^v//'`
pkgtarname=${package}-${pkgdotver}
make_tarball_opts=(-d bin:lib:man -F "${product_dir}" "${package}" "${pkgver}" "${basequal}" NO_FLAVOR)

get_this_dir
get_ssibuildshims

source define_basics NO_TYPE NO_DEBUG_SOURCE NO_FQ_DIR

if [ "${maketar}" = "tar" ] && [ -f "${pkgdir}.version/NULL_${basequal}" ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball "${make_tarball_opts[@]}"
   exit 0
fi

echo "building ${package} for ${OS}-${plat}"

# -------------------------------------------------------------------
# package dependent stuff goes here
# -------------------------------------------------------------------

mkdir -p ${blddir} 
if [ ! -d ${blddir} ]
then
   echo "ERROR: failed to create ${blddir}"
   exit 1
fi

if [ ${OS1} = "Darwin" ]
then
   PATH=`dropit /usr/bin/get-cert $PATH`
fi

# declare now so we can setup
# fake ups declare
fakedb=${product_dir}/${package}/${pkgver}/fakedb
${SSIBUILDSHIMS_DIR}/bin/fake_declare_product ${product_dir} ${package} ${pkgver} ${basequal} NO_FLAVOR || \
  ssi_die "fake declare failed"

# setup
setup -B ${package} ${pkgver} -q ${basequal} -z ${fakedb}:${product_dir}:${PRODUCTS} || ssi_die "fake setup failed"

set -x

# work in a build directory, which will not be part of any distribution
cd ${blddir} || ssi_die "Unable to cd into ${blddir}"
tar xf ${tardir}/${pkgtarname}.tar.gz || ssi_die "Failed to untar ${pkgtarname}.tar.gz"
cd ${package}-${pkgdotver} || ssi_die "Failed to cd into ${package}-${pkgdotver}"
site_packages_dir="${pkgdir}/lib/python2.7/site-packages/"
mkdir -p ${site_packages_dir} || ssi_die "Failed to create the site_packages directory ${site_packages_dir}"
python setup.py install --prefix ${pkgdir} || ssi_die "python setup.py install failed"
python -c "import pygccxml" || ssi_die "python failed to find pygccxml package"

set +x

if [ ! -d ${pkgdir}/lib ]
then
   echo "ERROR: failed to create ${pkgdir}/lib"
   echo "       Something is very wrong"
   exit 1
fi

# real ups declare
${SSIBUILDSHIMS_DIR}/bin/declare_product ${product_dir} ${package} ${pkgver} ${basequal} NO_FLAVOR || ssi_die "failed to declare ${package} ${pkgver}"

# -------------------------------------------------------------------
# common bottom stuff
# -------------------------------------------------------------------

# this should not complain
echo "Finished building ${package} ${pkgver}"
setup -B ${package} ${pkgver} -q ${basequal} -z ${product_dir}:${PRODUCTS}
echo "pygccxml is installed at ${PYGCCXML_DIR}"

# this must be last

if [ "${maketar}" = "tar" ] &&  [ -f "${pkgdir}.version/NULL_${basequal}" ]
then
  ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball "${make_tarball_opts[@]}"
fi

exit 0
